@@ -1,17 +1,16 @@
 import sys
-
 from typing import TypeVar
 
 from flask import Flask
 from flask_injector import FlaskInjector, request
 from flask_restx import Api
-from injector import Injector, Binder
+from injector import Injector, Binder,singleton
 from werkzeug.utils import redirect
 
-from ...api.base.controller_base import Controller
 from ...api.base import ResourceBase
+from ...api.base.controller_base import Controller
 from ...configuration.models.api import ApiConfig
-from ...configuration.models.application import  ApplicationConfig
+from ...configuration.models.application import ApplicationConfig
 from ...logging.loggers.console.console_logger import ConsoleLogger
 
 T = TypeVar('T')
@@ -46,18 +45,20 @@ class ApiProvider:
         if self.app is not None:
             self.binder.bind(
                 interface=Flask,
-                to=self.app
+                to=self.app,
+                scope=singleton
             )
         if self.api is not None:
             self.binder.bind(
                 interface=Api,
-                to=self.api
+                to=self.api,
+                scope=singleton
             )
         for controller in ResourceBase.__subclasses__():
             self.binder.bind(
                 interface=controller,
                 to=controller,
-                scope=request,
+                scope=request
             )
 
     def initialize_flask(self):
@@ -86,7 +87,8 @@ class ApiProvider:
 
     def find_resources(self):
         for resource in ResourceBase.__subclasses__():
-            if resource.__module__ in sys.modules and sys.modules[resource.__module__].__file__.startswith(self.application_config.root_directory):
+            if resource.__module__ in sys.modules and sys.modules[resource.__module__].__file__.startswith(
+                    self.application_config.root_directory):
                 namespace = None
                 namespace_name = None
                 route = None
@@ -96,7 +98,7 @@ class ApiProvider:
                     namespace_name = resource.namespace_name
                 if hasattr(resource, 'route'):
                     route = resource.route
-                
+
                 con = Controller(
                     cls=resource,
                     api=self.api,
